#
#
# This file is part of ganglia_tools
#
# Dave Carroll - davecarrollno@gmail.com 
#


def loglib(logfile,message):
    ''' Generic logging function for Ganglia metric modules.


    In your program, define a logfile like so:
        logfile = '/var/log/nanigans/test.log'
        In your program call this function like so:
        loglib(logfile,'INFO:  Starting test app')

    You can also silence by adding to your program:
        logging.disable(logging.DEBUG)
    '''

    import logging
    import read_config as cfg

    #readConfig()   # todo: enable options in cfg to control logging

    #logLevel = 'logging.'+cfg.logLevel


    logging.basicConfig(level=logging.INFO, format="%(asctime)s - %(name)s - %(levelname)s Thread-%(thread)d - %(message)s", filename=logfile)

    logging.info(message)

    return()



########################################
#
# This file part of the gangliarest package
#
# https://pypi.python.org/pypi/gangliarest
#
# https://github.com/dcarrollno/Ganglia-Modules/wiki/GangliaRest-API:-Part-I
#
# Dave Carroll - davecarrollno@gmail.com
#
########################################

import requests
import json
from loglib import loglib
import read_config as cfg

cfg.readConfig()


class CheckforUpdates(object):
    ''' Class to check pypi for new updates to gangliarest '''

    repo = 'https://pypi.python.org/pypi/{package}/json'


    def __init__(self,pkg):
        ''' pkg is the pkg we want to check '''

        self.pkg = pkg


    def updateCheck(self):
        ''' Check for update at pypi'''


        try:
            from packaging.version import parse

        except ImportError:
            print("Error importing packaging")
            from pip._vendor.packaging.version import parse


        req = requests.get(self.repo.format(package=self.pkg))

        avail_version = parse('0')
        if req.status_code == requests.codes.ok:
            j = json.loads(req.text.encode(req.encoding))
            if 'releases' in j:
                releases = j['releases']
                for release in releases:
                    ver = parse(release)
                    if not ver.is_prerelease:
                        avail_version = max(avail_version, ver)

        return str(avail_version)


    
    def installedCheck(self):
        ''' Method to check currently installed python
            package version '''

        import pip

        for dist in pip.get_installed_distributions():        
            #print(dist.project_name,dist.version)
            if dist.project_name == self.pkg:
                curr_pkg = dist.project_name
                curr_ver = dist.version

        return str(curr_ver)



    def compareCheck(self):
        ''' This method compares what is available to
            what we have installed as known by pip '''
            

        try:
            avail_version = self.updateCheck()
            installed_version = self.installedCheck() 

            #print("The installed version is: %s" % installed_version)
            #print("The available version is: %s" % avail_version)
            loglib(cfg.logfile,"Notice: The installed version of %s is %s" % (self.pkg,installed_version))

            if installed_version != avail_version:
                #print("New version available")
                loglib(cfg.logfile,"NOTICE: gangliarest-%s is available. Run 'pip install gangliarest --upgrade' to get the latest." % avail_version)
                update_msg = True
                return(avail_version,installed_version,update_msg)

            else:
                update_msg = False
                return(avail_version,installed_version,update_msg)

        except:
            # Software update check failed - not fatal
            pass



if __name__ == '__main__':
    
    # Debug
    myHandle = CheckforUpdates('gangliarest')
    inst = myHandle.compareCheck()





#!/usr/bin/python

import os
import sys
import re
import web
import time
import signal
import threading
import netifaces as ni
import get_metric_value as gmv
import read_config as cfg
from check_redis import Check_Redis_GangliaRest
from loglib import loglib
import indexer
import update_notify


''' /* This module requires:
       easy_install web.py
       pip install netifaces
   */
'''

web.config.debug = False
statefile = cfg.statsFile 



class GangliaRest(object):
    ''' Here we prime the web api to accept specific requests for
        metrics. Requests must match the urls section '''


    def __init__(self,host='0.0.0.0',port=8653):

        self.host = cfg.restHost
        self.port = cfg.restPort


        # Specific requets assigned to class. 

        urls = ( '/node/(.*)/get_metric/(.*)', 'GetMetric',
                 '/test(.*)', 'Test' )

        app = web.application(urls,globals())
        web.httpserver.runsimple(app.wsgifunc(), (self.host,self.port))

        loglib(cfg.logfile,"INFO: Started GangliaRest on IP %s and port %s" % (self.host,self.port))



    def printit(self):

        print("Listening on %s with port %s" % (self.host,self.port))



class Test(object):

    def GET(self,arg):
        resp = "Hello"+arg
        return(resp)



class GangliaRestScheduler(object):
    ''' The GangliaRestScheduler is a background process that
        will run user-defined jobs on an approximate schedule 
        or handle internal operations such as sw update checking
        and cache priming. '''

    primed = False		# default for cache primed
    swupdate_checked = False    # default for sw update status

    def __init__(self, interval=60):
        ''' The interval variable is not user defined ''' 


        self.__interval = interval
        self.__swupdateFreq = 86400 

        thread = threading.Thread(target=self.schedulerDaemon, args=())
        thread.daemon = True                            # Daemonize thread
        thread.start()                                  # Start the execution


    def runSwUpdate(self):
        ''' This method checks periodically for new gangliarest releases '''

        self.swupdate_now = time.time()
        
        ''' We want to check for new software releases on GangliaRest start up
            but then, only once per day thereafter. We assume logrotate may
            be configured to rotate daily on most systems so we hope our update
            message appears and is caught in a daily log. '''

        if not self.swupdate_checked: 
            try:
                sw_update = update_notify.CheckforUpdates('gangliarest')
                check = sw_update.compareCheck() 
                self.swupdate_checked = True
                self.swupdate_last_check = time.time()
            except:
                # a sw update check failure is not fatal to operations
                pass

        if self.swupdate_last_check: 
            self.swupdate_diff = self.swupdate_now - self.swupdate_last_check
            if self.swupdate_diff > self.__swupdateFreq:
                try:
                    sw_update = update_notify.CheckforUpdates('gangliarest')
                    check = sw_update.compareCheck()
                    self.swupdate_checked = True
                    self.swupdate_last_check = time.time()
                except:
                    # a sw update check failure is not fatal to operations
                    pass



    def runIndexer(self):
        ''' This method is responsible for running the Indexer at both
            internal and user-defined times. '''

        self.indexer_now = time.time()
       
        # Primer 
        if not self.primed:
            loglib(cfg.logfile,"INFO: INDEXER: Running Indexer for first time to prime cache.")
            try:
                firstrun_indexer = indexer.GangliaIndexer()
                firstrun_indexer.indexTimer()
                self.indexer_last_check = time.time()
                self.primed = True
            except:
                loglib(cfg.logfile,"ERROR: INDEXER failed to prime cache on first run.")
                self.primed = False

        try:
            if self.indexer_last_check:
                self.indexer_diff = self.indexer_now - self.indexer_last_check
                if self.indexer_diff > cfg.indexFreq:
                    loglib(cfg.logfile,"INFO: GangliaRest scheduler running Indexer on schedule. Starting indexing")
                    run_indexer = indexer.GangliaIndexer()
                    run_indexer.indexTimer()
                    self.indexer_last_check = time.time() 
                else:
                    #print("Not time to run indexer")  # debug
                    #loglib(cfg.logfile,"INFO: Timer indicates no need to run indexing. Sleeping for now")
                    pass
        except:
            # Setting first marker
            self.indexer_last_check = self.indexer_now



    def schedulerDaemon(self):
        ''' This method lists the scheduled jobs that need to be run. Add new methods
            under this class and then list the calls here to have them run. By default
            these jobs are checked every 60 secs to see if they meet criteria to run ''' 

        while True:

            # See if time to run the Indexer - This may run to prime the cache 
            # but is otherwise user-configurable in /etc/GangliaRest.cfg
            self.runIndexer()

            # See if time to run software update check
            self.runSwUpdate()
               
 
            # Scheduled jobs are listed above 
            time.sleep(self.__interval)



class GetMetric(object):
    ''' Responsible for getting the requested Ganglia
        metric last val '''

    reqsCount = 0
    respCount = 0
    errorCount = 0

    def __init__(self):
        ''' Here we keep track of requests, responses and errors as we
            like to trend those too in Ganglia using another module  '''


    def printit(self):
        print("Reqs %s" % reqsCount)
        print("Resp %s" % respCount)
        print("Error %s" % errorCount)


    def locate_file(self,node,file):
        ''' Here we need to find where the metric lives in the Ganglia
            tree. We also need to account for nodes that are named
            fully-qualified vs. not or searches will fail to match '''


        for dirName, subdirList, fileList in os.walk(cfg.rrdDir):


            loglib(cfg.logfile,"Node passed in was %s" % node)
            if node in subdirList or node+'.'+cfg.domain in subdirList:

		if os.path.abspath(dirName+'/'+node+'/'):
	            loglib(cfg.logfile,"Node %s found in dirName %s" % (node,dirName))
	            location = os.path.abspath(dirName+'/'+node+'/')
		else:
		    # Likely this is either a fqdn being passed in or needs to be
		    if node.endswith('.'+cfg.domain):
  		        node = re.sub('.'+cfg.domain,'',node)
		    else:
			node = node+'.'+cfg.domain

		    location = os.path.abspath(dirName+'/'+node+'/')
		    loglib(cfg.logfile,'Path is %s' % location)

            else:
		loglib(cfg.logfile,"Node %s NOT found in dirName %s" % (node,dirName))
		pass

        return(location)



    def GET(self,node='None',req='None'):
        ''' pass metric req list to get_metric_value '''

        self.metric_list = []
        self.node = node
        self.req = req+'.rrd'


        loglib(cfg.logfile,'REQUEST: request for metric %s on node %s' % (self.req,self.node))

        try:
	    locateDir = Check_Redis_GangliaRest(self.node)
            self.hostLocation = locateDir.redis_lookup()
        except:
            print("Error: Node not found in Redis cache or on filesystem")
            return('Not Found')

        if self.hostLocation is None:
            loglib(cfg.logfile,"WARN: Request for %s yielded no results. Did you set domain correctly in GangliaRest.cfg? Double-check your API request." % self.node)
            # Return a simple error for scripts to parse
            return('Not_Found') 
 
        self.metric = [i for i in os.listdir(self.hostLocation) if i == self.req]

        #loglib(cfg.logfile,'INFO: Found location as %s' % self.hostLocation)
        #loglib(cfg.logfile,'INFO: Checking metric %s' % self.metric)

        GetMetric.reqsCount +=1

        self.metric_list.append(self.req)

        #loglib(cfg.logfile,'Appending %s to metric_list' % self.metric)
        #loglib(cfg.logfile,'Sending %s and %s to gmv' % (self.hostLocation,self.metric_list))

        ans = gmv.GetMetricValue(self.hostLocation,self.metric_list)

        try:
            for k,v in ans.to_sort.items():
                loglib(cfg.logfile,"RESPONSE: returning value of %s for metric %s" % (k,v))
                GetMetric.respCount +=1
        except Exception as e:
            GetMetric.errorCount +=1
            #print(e)
            loglib(cfg.logfile,"ERROR: Error thrown was %s" % e)

        with open(statefile,'w') as f:
            f.write("Reqs: %d\n" % GetMetric.reqsCount)
            f.write("Resp: %d\n" % GetMetric.respCount)
            f.write("Errs: %d\n" % GetMetric.errorCount)


        return(v)




def set_exit_handler(func):
    signal.signal(signal.SIGTERM, func)

def on_exit(sig, func=None):
    print "exit handler triggered"
    loglib(cfg.logfile,'WARN: Exiting program')
    sys.exit(1)

def get_Eth0():
    ''' We want to ensure we only listen on internal IP
        which is protected from the outside world '''

    ni.ifaddresses('eth0')
    ip = ni.ifaddresses('eth0')[2][0]['addr']
    return(ip)


if __name__ == "__main__":

    set_exit_handler(on_exit)

    listenIp = get_Eth0()

    cfg.readConfig()
    jobs_scheduler = GangliaRestScheduler()
    gangliarest = GangliaRest(host=listenIp,port=8653)



########################################
#
# This file part of the gangliarest package
#
# https://pypi.python.org/pypi/gangliarest
#
# https://github.com/dcarrollno/Ganglia-Modules/wiki/GangliaRest-API:-Part-I
#
# Dave Carroll - davecarrollno@gmail.com
#
########################################

import os
import sys
import time
import redis
import read_config as cfg
from loglib import loglib


cfg.readConfig()

rootDir = cfg.rrdDir 


class GangliaIndexer(object):
    ''' Indexer class. This class contains two methods
        which are responsible for indexing operations. Indexing
        the locations of Ganglia node directories into Redis speeds
        up access and response time for API clients requesting metric
        info.  '''

    # Set in /etc/GangliaRest.cfg and defines how often we index
    indexer_frequency = cfg.indexFreq 
    index_adds = 0


    def __init__(self):
        ''' Constructor '''


    def indexer(self):
        ''' The indexer method is responsible for establishing
            a connection to the local Redis DB, walking the Ganglia
            RRD tree and indexing directory locations into Redis. We
            do this so we do not need to walk the entire filesystem 
            looking for metric locations. '''
 
        
        r = redis.Redis(
            host = cfg.redisHost,
            port = cfg.redisPort,
            db = cfg.redisDb,
            password = cfg.redisAuth)
 

        try:
            for dirName, subdirList, fileList in os.walk(rootDir):
                for host in subdirList:
                    location = os.path.abspath(dirName+'/'+host)
                    if host.startswith('__SummaryInfo__'):
                        continue
                    else:
                        try:
                            #print("Adding host %s to Redis" % host) 
                            r.setex(host,location,cfg.redisTtl)
                            self.index_adds +=1
                            stat = True
                        except:
                            print("ERROR: Error inserting host into Redis")
                            loglib(cfg.logfile,"ERROR: Indexer failed to index host %s" % host)
                            stat = False
        except Exception as e:
            #print("Failed to scan filesystem")
            loglib(cfg.logfile,"ERROR: INDEXER failed. Error reported was %s" % e)
            stat = False


        return(stat)  # in case we want a return status


    def indexTimer(self):
        ''' The indexTimer method historically was responsible for managing
            timed runs - whether to run an indexing or not but has been 
            depreciated and now just acts as a calling method. This was when
            this particular class used multithreading but no longer does. ''' 

        try:

            #print("Running indexer on schedule")
            loglib(cfg.logfile,"INFO: INDEXER starting scheduled operations...")
            runner = self.indexer()
            if runner:
                #print("Completed indexing")
                loglib(cfg.logfile,"INFO: INDEXER completed run...Added %s entries to Redis" % self.index_adds)
                return()
            else:
                print("Indexing failed receiving a False from the indexer method.")
                return()

        except Exception as e:
            #print("Indexing failed. Exception thrown was %s" % e)
            loglib(cfg.logfile,"ERROR: INDEXER threw an error of %s" % e)

        return()


if __name__ == "__main__":

    cfg.readConfig()   

    # Debugging
    #myHandle = GangliaIndexer()
    #while True:
    #    last_run = myHandle.indexTimer()
    #    time.sleep(15)




########################################
#
# This file part of the gangliarest package
# 
# https://pypi.python.org/pypi/gangliarest
#
# https://github.com/dcarrollno/Ganglia-Modules/wiki/GangliaRest-API:-Part-I
#
# Dave Carroll - davecarrollno@gmail.com
#
########################################

import os
import re
import sys
import redis
from redis import ConnectionError
from loglib import loglib
import read_config as cfg

cfg.readConfig()

class Check_Redis_GangliaRest(object):
    ''' This class is responsible for handling our Ganglia RRD locations.
        We use a Redis DB instance to cache file system locations to lessen
        walking the filesystem when locating metrics under the rrd tree. ''' 


    rootDir = cfg.rrdDir 
    logfile = cfg.logfile 

    def __init__(self,hostname):
        ''' We are looking for our hostnames in our rrd tree '''

        self.hostname = hostname

        ''' We have to aquire both hostname and fqdn to test '''

        if self.hostname.endswith(cfg.domain):
            self.non_fqdn = self.hostname.split('.',1)[0]
            self.fqdn = self.hostname
             
        else:
            self.non_fqdn = self.hostname
            self.fqdn = self.hostname+'.'+cfg.domain



    def is_redis_available(self,conn):
        ''' Check if Redis running and available - if not write hint to logfile ''' 

        try:
            conn.get(None)  # getting None returns None or throws an exception

        except (redis.exceptions.ConnectionError, 
            redis.exceptions.BusyLoadingError):
            if os.path.isfile('var/run/redis/redis.pid'):
                loglib(self.logfile,"WARN: Redis pid file exists but problem connecting to Redis")
            else: 
                loglib(self.logfile,"ERROR: Redis is not responding and no pidfile was found. Ensure Redis is running")

        try:
            conn.ping()

        except:
            loglib(self.logfile,"ERROR: Redis is not reachable. Ensure it is configured correctly, and check /etc/GangliaRest.cfg for proper configuration.")
            return False

        return True


    def redis_lookup(self):

        r = redis.Redis(
	    host = cfg.redisHost,
  	    port = cfg.redisPort,
            db = cfg.redisDb,
            password = cfg.redisAuth)

        redisStatus = self.is_redis_available(r)

	# Check our cache for host location
        if r.exists(self.fqdn):
            self.location = r.get(self.fqdn)
            loglib(self.logfile,"CACHE HIT: Redis: returning %s in Check_Redis_GangliaRest:redis_lookup" % self.location)
            return(self.location)

        elif r.exists(self.non_fqdn):
            self.location = r.get(self.non_fqdn)
            loglib(self.logfile,"CACHE HIT: Redis: returning %s in Check_Redis_GangliaRest:redis_lookup" % self.location)
            return(self.location)   
 
	else:
	    ''' location not found in cache, find in filesystem and load into cache
                to improve lookup performance for API requests. Because we may have been
                passed either a hostname or fqdn to search for, we'll have to look for both '''

	    try:
	        for dirName, subdirList, fileList in os.walk(self.rootDir):
                    for host in subdirList:
			''' We have to account for hosts that were named fqdn
			    or simply by hostname, or we will fail to locate '''
                        m = re.match(self.non_fqdn, host)
                        if m:
			    self.hostname = host	# reset the host to the correct name on fs
			    #loglib(self.logfile,"INFO: Host being set as %s" % self.hostname)
		            self.location = os.path.abspath(dirName+'/'+self.hostname)

			    ''' Now we need to add to our Redis cache with a TTL of one day
				to account for transitory systems like VM's that spin down '''
			    try:
			        #print("Setting key for %s and val %s" % (self.hostname,self.location))
			        r.setex(self.hostname, self.location, cfg.redisTtl)
			        return(self.location)

	                    except:
				loglib(self.logfile,"ERROR: Error writing to Redis under Check_Redis_GangliaRest:redis_lookup")
			        exit(1)

		        else:
			    #loglib(self.logfile,"ERROR: Unable to match requested host %s using match %s in rrdtree under Check_Redis_GangliaRest:redis_lookup" % (host,self.non_fqdn))
			    continue  # we don't want to log every miss


            except:
	        loglib(self.logfile,"ERROR: Unable to find host %s or write to Redis requested host in rrdtree under Check_Redis_GangliaRest:redis_lookup" % host)


if __name__ == "__main__":

    ''' Test code here ''' 

    handle = Check_Redis_GangliaRest(host_here)
    handle.redis_lookup()



########################################
#
# This file part of the gangliarest package
#
# https://pypi.python.org/pypi/gangliarest
#
# https://github.com/dcarrollno/Ganglia-Modules/wiki/GangliaRest-API:-Part-I
#
# Dave Carroll - davecarrollno@gmail.com
#
########################################


import os,sys,re
from subprocess import Popen,PIPE,STDOUT
import read_config as cfg
from loglib import loglib


class GetMetricValue(object):
    ''' Here we look up the value of the metric that passed the expiration test. '''


    def __init__(self,nodepath,activeList):
        ''' '''

        self.nodepath = nodepath
        self.activeList = activeList
        logfile = 'None' # override with instance attribute


        # Store metric values in a dict so we can sort next by top5
        self.to_sort = {}


        for self.metric in self.activeList:
            #print("Checking metric %s located at path %s" % (self.metric,self.nodepath))
            #loglib(cfg.logfile,"INFO: Checking metric %s located at %s" % (self.metric,self.nodepath))
            cmd3 = ' | grep "last_ds"'
            newcmd = '/usr/bin/rrdtool info '+ self.nodepath+'/'+self.metric + cmd3
            # Get last_ds and file name from rrdtool for each api_https metric
            p1 = Popen(newcmd, shell=True, stdin=PIPE, stdout=PIPE, stderr=STDOUT, close_fds=True)
            output1 = p1.stdout.read()

            try:
                self.lastds,self.val = output1.split('=')
                self.val = self.val.replace('"','').strip()

                if isinstance(self.val, int):
                    self.val = int(self.val)
                if isinstance(self.val, float):
                    self.val = float(self.val)

                self.to_sort[self.metric]=self.val
                #print("Metric %s has a value of %s" % (self.metric,self.val))
                loglib(logfile,'INFO: LastDS for %s is %s' % (self.metric,self.val))

            except Exception as e:
                loglib(logfile,'ERROR: Unable to get last ds for metric %s. Error thrown was %s' % (self.metric,e))
                #print e
                #print("Unable to get last ds for metric %s" % self.metric)
	        continue


if __name__ == "__main__":


    nodepath = '/var/lib/ganglia/rrds/<cluster>/<node>'
    metric = ['diskstat_sda_io_time.rrd']

    res = GetMetricValue(nodepath,metric)



from setuptools import setup, find_packages
from setuptools.command.install import install
from codecs import open
from os import path
import os
import sys

here = path.abspath(path.dirname(__file__))

class PostInstall(install):
    """Customized setuptools install command - prints a friendly greeting."""

    def run(self):
        print "Running custom install script"
        ver = sys.version_info[:2]
        if ver == (2, 6):
            version = '2.6'
        if ver == (2, 7):
            version = '2.7'
        pkg='/usr/lib/python'+version+'/site-packages/gangliarest' 
 
        mode = 0751
        src = '/usr/lib/python'+version+'/site-packages/gangliarest/gangliaRest.py'
        dst = '/usr/local/sbin/GangliaRest'
        install.run(self)
        os.symlink(src,dst) 
        for dirpath, dirnames, filenames in os.walk(pkg):
            for filename in filenames:
                path = os.path.join(dirpath, filename)
                os.chmod(path, 0751)
        


setup(
    name='gangliarest',
    version='0.1.7',
    author="Dave Carroll",
    author_email="davecarrollno@gmail.com",
    description=("A ReSTFUL frontend to Ganglia exposing metrics via HTTP."),
    keywords = "Ganglia API REST Web frontend metrics", 
    url="https://github.com/dcarrollno/Ganglia-Modules/wiki/GangliaRest-API:-Part-I",
    download_url="https://github.com/dcarrollno/Ganglia-Modules/tree/master/GangliaRest",
    packages=['gangliarest'],
    long_description=open('README.txt').read(),
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: System Administrators',
        'Topic :: System :: Monitoring',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7', 
        'Operating System :: POSIX :: Linux',
    ],
    install_requires=["gns3-netifaces","web.py","redis","packaging"],
    include_package_data=True,
    data_files=[
        ('/etc/', ['etc/GangliaRest.cfg']),
        ('/etc/init.d/', ['etc/GangliaRest']),
    ],
    cmdclass={'install': PostInstall},
    
)



########################################
#
# This file part of the gangliarest package
#
# https://pypi.python.org/pypi/gangliarest
#
# https://github.com/dcarrollno/Ganglia-Modules/wiki/GangliaRest-API:-Part-I
#
# Dave Carroll - davecarrollno@gmail.com
#
########################################


import ConfigParser
import sys 
import re


redis_conf_file = '/etc/redis.conf'

def get_redis_auth():
    with open(redis_conf_file, 'r') as f:
        for line in f:
            if line.startswith('requirepass'):
                (label,pw) = line.split()
                return(pw)
            if line.startswith('#requirepass'):
                return(False)
 

def readConfig():
    ''' Here we ingest the /etc/GangliaRest.cfg options. These options are only
        read once at startup of GangliaRest so any change to options requires a restart. '''


    global Config,redisHost,redisAuth,redisPort,redisDb,logfile,rrdDir,restPort, \
           restHost,domain,indexFreq,redisTtl,logLevel,statsFile


    Config = ConfigParser.ConfigParser()
    Config.read("/etc/GangliaRest.cfg")

    restHost = Config.get('Globals','restHost')
    restPort = Config.get('Globals','restPort')
    restPort = int(restPort)
    domain = Config.get('Globals','domain')
    logfile = Config.get('Globals','logfile')
    logLevel = Config.get('Globals','logLevel')
    rrdDir = Config.get('Globals','rrdDir')
    statsFile = Config.get('Globals','statsFile')

    redisHost = Config.get('Redis','redisHost')
    redisPort = Config.get('Redis','redisPort')
    redisPort = int(redisPort)
    redisDb = Config.get('Redis','redisDb')
    redisDb = int(redisDb)
    redisTtl = Config.get('Redis','redisTtl')
    redisTtl = int(redisTtl)
    redisAuth = get_redis_auth()

    indexFreq = Config.get('Indexer','indexFreq')
    indexFreq = int(indexFreq)


if __name__ == "__main__":

    readConfig()
    print(logLevel)
